Package: npGSEA
Type: Package
Title: Permutation approximation methods for gene set enrichment
        analysis (non-permutation GSEA)
Version: 1.49.0
Date: 2015-5-6
Author: Jessica Larson and Art Owen
Maintainer: Jessica Larson <larson.jess@gmail.com>
Imports: Biobase, methods, BiocGenerics, graphics, stats
Suggests: ALL, genefilter, limma, hgu95av2.db, ReportingTools,
        BiocStyle
Depends: GSEABase (>= 1.24.0)
Description: Current gene set enrichment methods rely upon permutations
        for inference.  These approaches are computationally expensive
        and have minimum achievable p-values based on the number of
        permutations, not on the actual observed statistics.  We have
        derived three parametric approximations to the permutation
        distributions of two gene set enrichment test statistics.  We
        are able to reduce the computational burden and granularity
        issues of permutation testing with our method, which is
        implemented in this package. npGSEA calculates gene set
        enrichment statistics and p-values without the computational
        cost of permutations.  It is applicable in settings where one
        or many gene sets are of interest.  There are also built-in
        plotting functions to help users visualize results.
License: Artistic-2.0
biocViews: GeneSetEnrichment, Microarray, StatisticalMethod, Pathways
Collate: 'getIncidence.R' 'miscFunctions.R' 'miscDataPrepFunctions.R'
        'npGSEA.R' 'AllClasses.R' 'AllGenerics.R'
        'npGSEAResultBeta-accessors.R' 'npGSEAResultChiSq-accessors.R'
        'npGSEAResultNorm-accessors.R' 'npGSEAPlot-methods.R'
        'show-methods.R' 'pValues-methods.R'
Packaged: 2026-04-29 00:06:52 UTC; biocbuild
git_url: https://git.bioconductor.org/packages/npGSEA
git_branch: devel
git_last_commit: ec632c0
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
