setGeneric("geneSetName", function(object) 
                            standardGeneric("geneSetName"))

setGeneric("stat", function(object) standardGeneric("stat"))

setGeneric("sigmaSq", function(object) standardGeneric("sigmaSq"))

setGeneric("pValues", function(object) standardGeneric("pValues"))

setGeneric("pTwoSided", function(object) standardGeneric("pTwoSided"))

setGeneric("pLeft", function(object) standardGeneric("pLeft"))

setGeneric("pRight", function(object) standardGeneric("pRight"))

setGeneric("xSet", function(object) standardGeneric("xSet"))

setGeneric("betaHats", function(object) standardGeneric("betaHats"))

setGeneric("npGSEAPlot", function(object) 
                    standardGeneric("npGSEAPlot"))

setGeneric("zStat", function(object) standardGeneric("zStat"))

setGeneric("betaStat", function(object) standardGeneric("betaStat"))

setGeneric("alphaValue", function(object) standardGeneric("alphaValue"))

setGeneric("betaValue", function(object) standardGeneric("betaValue"))

setGeneric("chiSqStat", function(object) standardGeneric("chiSqStat"))

setGeneric("DF", function(object) standardGeneric("DF"))
